Blob Blame History Raw
From 7dab681ec8e28c3174d00729b76f109e91e408f9 Mon Sep 17 00:00:00 2001
From: Frank Bossen <frank@bossentech.com>
Date: Mon, 29 Dec 2014 18:38:36 +0100
Subject: [PATCH 1/3] Check image size when reading targa file

Throw an error when image width or height is 0.

Fixes mozilla/mozjpeg#140, closes #7.
---
 rdtarga.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/rdtarga.c b/rdtarga.c
index 4c2cd26..d305f1f 100644
--- a/rdtarga.c
+++ b/rdtarga.c
@@ -363,7 +363,8 @@ start_input_tga (j_compress_ptr cinfo, cjpeg_source_ptr sinfo)
   if (cmaptype > 1 ||		/* cmaptype must be 0 or 1 */
       source->pixel_size < 1 || source->pixel_size > 4 ||
       (UCH(targaheader[16]) & 7) != 0 || /* bits/pixel must be multiple of 8 */
-      interlace_type != 0)	/* currently don't allow interlaced image */
+      interlace_type != 0 ||		/* currently don't allow interlaced image */
+      width == 0 || height == 0)	/* image width/height must be non-zero */
     ERREXIT(cinfo, JERR_TGA_BADPARMS);
   
   if (subtype > 8) {
-- 
2.17.2